from distutils.core import setup

setup(
    name='truerandomdice',
    version='0.1',
    packages=['truerandomdice'],
    url='https://github.com/EarthModule/TrulyRandomDiceThrower',
    download_url='https://github.com/EarthModule/TrulyRandomDiceThrower/releases/tag/0.1',
    license='',
    author='toni nurmi',
    author_email='toni.nurmi@hotmail.com',
    description=''
)
